OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Se ha detectado una nueva ubicación de inicio de sesión",
    "More info about the suspicious IP address available on %s" : "Más información acerca de la dirección IP sospechosa está disponible en %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Se ha detectado un nuevo inicio de sesión en tu cuenta. La IP %s parece sospechosa. Si fuiste tu, puedes ignorar este mensaje. Si no, debes cambiar tu contraseña.",
    "Open %s ↗" : "Abrir %s ↗",
    "Suspicious Login" : "Suspicious Login",
    "New login detected" : "Nuevo inicio de sesión detectado",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detectar y advertir sobre las IP sospechosas que inician sesión en Nextcloud\n\t"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
